(function() {

    var spinnerOptions = {
        lines: 13, // The number of lines to draw
        length: 9, // The length of each line
        width: 10, // The line thickness
        radius: 33, // The radius of the inner circle
        corners: 1, // Corner roundness (0..1)
        rotate: 0, // The rotation offset
        direction: 1, // 1: clockwise, -1: counterclockwise
        color: '#000', // #rgb or #rrggbb or array of colors
        speed: 1.4, // Rounds per second
        trail: 60, // Afterglow percentage
        shadow: false, // Whether to render a shadow
        hwaccel: true, // Whether to use hardware acceleration
        className: 'spinner', // The CSS class to assign to the spinner
        zIndex: 2e9, // The z-index (defaults to 2000000000)
        top: '50%', // Top position relative to parent
        left: '50%' // Left position relative to parent
    };

    var spinner = new Spinner(spinnerOptions);
    var port = chrome.extension.connect({
        name: 'background'
    });
    var evidenceFromText = $('#evidence-from-text');

    function getProjectOption(project) {
        var id = project.links[0].href.split('/').pop();
        return $('<option value="' + id + '" ' + ((project.current === true) ? ' selected' : '') + ' >' + project.data.name + '</option>');
    }

    $(document).ready(function() {
        port.onMessage.addListener(function(msg) {

            if (msg.type === 'update-projectlist') {
                if (msg.state === 'done') {
                    var $list = $('[data-id="project-list"]');
                    $list.empty();
                    if (msg.res && msg.res.data && msg.res.data.length > 0) {
                        for (var i in msg.res.data) {
                            var item = msg.res.data[i];
                            $list.append(getProjectOption(item));
                        }
                        $('[data-id="projectlist-container"]').show();
                    }
                }
            }

            if (msg.type === 'done-creating-note') {
                $('body').css({
                    'opacity': 1
                });
                spinner.stop();
                window.close();
            }

        });

        $('[data-id="projectlist"]').on('change', function() {
            port.postMessage({
                type: 'change-active-project',
                project_id: $('[data-id="projectlist"]').val()
            });
        });

        //send opened message, so that the login status
        //and the project list can be set out of the simple
        //cache implemented in the background.js
        // port.postMessage({type: 'popup-opened'});
        port.postMessage({
            type: 'get-projectlist'
        });

        $('#evidence-from-text, #paraphrasing, #comment').wysihtml5();


        var getSelection = function() {
            var selection = window.getSelection();
            var range = selection.getRangeAt(0);
            var div;
            if (range) {
                div = document.createElement('div');
                div.appendChild(range.cloneContents());
            }
            return div.innerHTML;
        };

        var codeString = '(' + getSelection + ')();';

        chrome.tabs.query({
            active: true
        }, function(tabArray) {
            chrome.tabs.executeScript(tabArray[0].id, {
                code: codeString
            }, function(result) {
                $('#easybib-note-title').val(result[0].replace(/<\/?[^>]+(>|$)/g, "").substr(0, 30));
                $('#evidence-from-text').data("wysihtml5").editor.setValue(result[0]);
            });
        });

        $('#save-note').click(function(e) {
            e.preventDefault();
            chrome.tabs.query({
              active: true
            }, function(tabArray){
                  var tabURL;
                  tabURL = tabArray[0].url;
                  var target = document.getElementsByTagName('body')[0];
                  spinner.spin(target);
                  var projectID = $('.project-list option:selected').val();
                  port.postMessage({
                      type: 'gonotebook',
                      content: {
                          'currentPageURL':tabURL,
                          'title': $('#easybib-note-title').val(),
                          'evidence': $('#evidence-from-text').val(),
                          'paraphrasing': $('#paraphrasing').val(),
                          'comment': $('#comment').val()
                      },
                      projectID: projectID
                  });
            });
            $('body').css({
                'opacity': 0.3
            });
        });

        $('#cancel-note').click(function() {
            close();
        });
    });

}());

